=====
pyGMM
=====

.. image:: https://img.shields.io/pypi/v/pygmm.svg
    :target: https://pypi.python.org/pypi/pygmm
    :alt: PyPi Cheese Shop

.. image:: https://img.shields.io/travis/arkottke/pygmm.svg
    :target: https://travis-ci.org/arkottke/pygmm
    :alt: Build Status

.. image:: https://readthedocs.org/projects/pygmm/badge/?version=latest&style=flat
    :target: https://pygmm.readthedocs.org
    :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/arkottke/pygmm/badge.svg?branch=master
    :target: https://coveralls.io/github/arkottke/pygmm?branch=master
    :alt: Test Coverage

.. image:: https://landscape.io/github/arkottke/pygmm/master/landscape.svg?style=flat
    :target: https://landscape.io/github/arkottke/pygmm/master
    :alt: Code Health

.. image:: https://img.shields.io/badge/license-MIT-blue.svg

Ground motion models implemented in Python.

* Free software: MIT license
* Documentation: https://pygmm.readthedocs.org.

Features
--------

Models currently supported:

* Atkinson & Boore (2006)

* Abrahamson, Silva, & Kamai (2014) with unit tests

* Boore, Stewart, Seyhan, & Atkinson (2014) with unit tests

* Campbell (2003)

* Campbell & Bozorgnia (2014) with unit tests

* Chiou & Youngs (2014) with unit tests

* Idriss (2014) with unit tests

* Pezeshk, Zandieh, & Tavakoli (2001)

* Tavakoli & Pezeshk (2005)


Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
